@@ -10,6 +10,10 @@ import pendulum
 import pkg_resources
 import psutil
 
+from . import job
+from . import plot_util
+from .reporting import abbr_path, phase_str
+
 
 def job_phases_for_tmpdir(d, all_jobs):
     '''Return phase 2-tuples for jobs running on tmpdir d'''
@@ -417,3 +421,29 @@ class Job:
         # TODO: check that this is best practice for killing a job.
         self.proc.resume()
         self.proc.terminate()
+
+
+def report_jdata(jobs, tmp_prefix='', dst_prefix='') -> list:
+    jobsr = list()
+    for i, j in enumerate(sorted(jobs, key=job.Job.get_time_wall)):
+        with j.proc.oneshot():
+            dictionary = {
+                'plotid': j.plot_id[:8],
+                'k': j.k,
+                'tmp': abbr_path(j.tmpdir, tmp_prefix),
+                'dst': abbr_path(j.dstdir, dst_prefix),
+                'wall': plot_util.time_format(j.get_time_wall()),
+                'phase': phase_str(j.progress()),
+                'tmpdisk': plot_util.human_format(j.get_tmp_usage(), 0),
+                'pid': j.proc.pid,
+                'stat': j.get_run_status(),
+                'mem': plot_util.human_format(j.get_mem_usage(), 1),
+                'user': plot_util.time_format(j.get_time_user()),
+                'sys': plot_util.time_format(j.get_time_sys()),
+                'io': plot_util.time_format(j.get_time_iowait()),
+                'freezed': plot_util.is_freezed(j),
+                'logfile': os.path.basename(j.logfile)
+            }
+            jobsr.append(dictionary)
+
+    return jobsr
